@@ -19,10 +19,11 @@ def register(excelFile: "Excel file containing the component data",
              subProject: "ATLAS Subproject" = "SE",
              institution: "Institute doing the registration" = "DESYHH",
              subType: "Component Subtype" = "THERMALFOAMSET_PETAL",
-             lambdaFunction: "Function that modifies the df (takes the df as argument, returns the modified df)" = None
+             lambdaFunction: "Function that modifies the df (takes the df as argument, returns the modified df)" = None,
+             sheetName: "Name or number of the excel sheet to process" = 0
              ):
     "Registering components from an excel file."
-    df = pd.read_excel(excelFile, header=1)
+    df = pd.read_excel(excelFile, header=1, sheet_name=sheetName)
     print(df)
     if lambdaFunction is not None:
         df = lambdaFunction(df)
